==> yass-1.07.tar.gz: yass-1.07/util.h <==
/*
 *  YASS 1.07
 *  Copyright (C) 2004,2005
 *  YASS Team
 *  Laurent Noe, Gregory Kucherov, Mikhail Roytberg, Christophe Valmir, Steven Corroy
 *  yass@loria.fr
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software contains code derived from the GNU libavl library.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef __UTIL_H_
#define __UTIL_H_

#include "global_var.h"

double dpow(double mant,int puis);
int ipow(int mant,int puis);
double C(int n,int k);
int size_int(int i);
void strnsub(char * buffer,char * motif,int n,char c);

/*=======================*
 *      Controls         *
 *=======================*/


/*
 * misc outputs 
 */

#define STATS
#define TRACE
#define COLOR
/*#define INLINE*/
#define CHOOSEAVLTREE
/*#define CHOOSERBTREE*/
/*
 * memory optimisation on assemble algorithm (slower but runnable on larger
 * sequences ...)
 */

/*#define MEMOPT
 */

/*
 * "gore" allocation of tuples to avoid malloc latency effects
 * -> only for tests ...
 */

/* #define GORE_ALLOC_TUPLE */
/* #define GORE_ALLOC_TUPLELIST */
/* #define GORE_ALLOC_TUPLE_SIZE     (8*MEGA) */
/* #define GORE_ALLOC_TUPLELIST_SIZE (4*MEGA) */


/* 
 * first nucleotide position is 0 or 1 
 */

#define BCOUNT 1                          
/* #define BCOUNT 0 */


/*
 * debug yass output options 
 */

/* #define DEBUG         */
/* #define DEBUGASSEMBLE */
/* #define DEBUGALIGN    */
/* #define DEBUGREGROUP  */

/*=================*
 * General Macros  *
 *=================*/

#define  RULE "-------------------------------------------------------------------------------\n"
#define DRULE "===============================================================================\n"
#define alphabet  4
#define LOOKUP(i) ((char)(lookup[(int)(i)]))
#define FALSE 0
#define TRUE  1
#define INFINITY  (int)(0x3f000000)
#define ABS(a)   ((a)>=(0)?(a):-(a)) 
#define MAX(a,b) ((a)>(b)?(a):(b))
#define MIN(a,b) ((a)>(b)?(b):(a))
#define MIN3(a,b,c) MIN((a),MIN((b),(c)))
#define MAX3(a,b,c) MAX((a),MAX((b),(c)))
#define OUTSTREAM (gv_outstream?gv_outstream:stdout)
#define KILO      (1024)
#define MEGA      (KILO*KILO)
#define AUTOMATADELPH 16
#define AUTOMATAMASK  0x0000ffff
#define ALIGN_EVERY_NB_ITER (4096*2)
#define NBL  80               /* number of colums for alignments and progress bar */
#define TREE_MAX_HEIGHT 256   /* red_black/avl_tree weight */

/* A(=0) becomes T(=1) et vise versa .
 * C(=2) becomes G(=3) et vise versa .
 */

#define PURIN(base)      (!((base)&0x01))
#define PYRIMIDIN(base)  ((base)&0x01))
#define COMPLEMENT(base) ((base<5)?(base)^0x01:base)


#define BLACK      0
#define RED        1
#define GREEN      2
#define ORANGE     3
#define BLUE       4
#define PINK       5
#define CYAN       6
#define WHITE      7

#ifdef COLOR
  #define SETCOLOR(std,foreground) {fprintf(std,"\033[%im",30+foreground);}
  #define SETBCOLOR(std,foreground) {fprintf(std,"\033[%im",30+foreground);}
  #define RESET(std) {fprintf(std,"\033[0m\n");}
#else
  #define SETCOLOR(std,foreground,background) 
  #define SETBCOLOR(std,foreground,background) 
  #define RESET(std)                           
#endif

#define  ASSERT(prt,errmessage) if(!(prt)){                                              \
  fprintf(stderr,"* Allocation Error :\"%s\", function \"%s()\"\n",#prt,#errmessage);    \
  RESET(stdout);                                                                         \
  RESET(stderr);                                                                         \
  exit(-1);                                                                              \
}

#define WARNING(errmessage)  {                                 \
	  fprintf(stderr,"* Warning : %s \n",#errmessage); \
}



#endif

==> yass-1.08.tar.gz: yass-1.08/util.h <==
/*
 *  YASS 1.08
 *  Copyright (C) 2004,2005
 *  YASS Team
 *  Laurent Noe, Gregory Kucherov, Mikhail Roytberg, Christophe Valmir, Steven Corroy
 *  yass@loria.fr
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software contains code derived from the GNU libavl library.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef __UTIL_H_
#define __UTIL_H_

#include "global_var.h"

double dpow(double mant, int puis);
int ipow(int mant, int puis);
double C(int n, int k);
int size_int(int i);
void strnsub(char *buffer, char *motif, int n, char c);

char *strndupLocal(char *string,int n);


/*=======================*
 *      Controls         *
 *=======================*/
/* Enable one cache
   Advantage : high speed
   But : allocated more memory 
 */
#define NO_CACHE


/*
 * misc outputs 
 */

#define STATS
#define TRACE
#define COLOR
/*#define INLINE*/
#define CHOOSEAVLTREE
/*#define CHOOSERBTREE*/
/*
 * memory optimisation on assemble algorithm (slower but runnable on larger
 * sequences ...)
 */

#define DBL_MAX 10e16
#define INT_MAX 2147483647

/*#define MEMOPT
 */

/*
 * "gore" allocation of tuples to avoid malloc latency effects
 * -> only for tests ...
 */

/* #define GORE_ALLOC_TUPLE */
/* #define GORE_ALLOC_TUPLELIST */
/* #define GORE_ALLOC_TUPLE_SIZE     (8*MEGA) */
/* #define GORE_ALLOC_TUPLELIST_SIZE (4*MEGA) */


/* 
 * first nucleotide position is 0 or 1 
 */

#define BCOUNT 1
/* #define BCOUNT 0 */


/*
 * debug yass output options 
 */

/* #define DEBUG         */
/* #define DEBUGASSEMBLE */
/* #define DEBUGALIGN    */
/* #define DEBUGREGROUP  */

/*=================*
 * General Macros  *
 *=================*/

#define  RULE "-------------------------------------------------------------------------------\n"
#define DRULE "===============================================================================\n"
#define alphabet  4
#define LOOKUP(i) ((char)(lookup[(int)(i)]))
#define FALSE 0
#define TRUE  1
#define INFINITY  (int)(0x3f000000)
#define ABS(a)   ((a)>=(0)?(a):-(a))
#define MAX(a,b) ((a)>(b)?(a):(b))
#define MIN(a,b) ((a)>(b)?(b):(a))
#define MIN3(a,b,c) MIN((a),MIN((b),(c)))
#define MAX3(a,b,c) MAX((a),MAX((b),(c)))
#define OUTSTREAM (gv_outstream?gv_outstream:stdout)
#define KILO      (1024)
#define MEGA      (KILO*KILO)
#define AUTOMATADELPH 16
#define AUTOMATAMASK  0x0000ffff
#define ALIGN_EVERY_NB_ITER (4096*2)
#define NBL  80			/* number of colums for alignments and progress bar */
#define TREE_MAX_HEIGHT 256	/* red_black/avl_tree weight */

/* A(=0) becomes T(=1) et vise versa .
 * C(=2) becomes G(=3) et vise versa .
 */

#define PURIN(base)      (!((base)&0x01))
#define PYRIMIDIN(base)  ((base)&0x01))
#define COMPLEMENT(base) ((base) ^ 0x01)


#define BLACK      0
#define RED        1
#define GREEN      2
#define ORANGE     3
#define BLUE       4
#define PINK       5
#define CYAN       6
#define WHITE      7

#ifdef COLOR
#define SETCOLOR(std,foreground) {fprintf(std,"\033[%im",30+foreground);}
#define SETBCOLOR(std,foreground) {fprintf(std,"\033[%im",30+foreground);}
#define RESET(std) {fprintf(std,"\033[0m\n");}
#else
#define SETCOLOR(std,foreground,background)
#define SETBCOLOR(std,foreground,background)
#define RESET(std)
#endif

#define  ASSERT(prt,errmessage) if(!(prt)){                                              \
  fprintf(stderr,"* Allocation Error :\"%s\", function \"%s()\"\n",#prt,#errmessage);    \
  RESET(stdout);                                                                         \
  RESET(stderr);                                                                         \
  exit(-1);                                                                              \
}

#define WARNING(errmessage)  {                                 \
	  fprintf(stderr,"* Warning : %s \n",#errmessage); \
}



#endif
